JQpy 1.0.0 documentation

# Welcome to JQpy’s documentation!

JQpy is Python binding for JQ (JSON processing language) that simply works on any platform (even Windows) and does not require compilation.

Quick example:

    >>> from jqpy import jq
    >>> jq('.results[] | {age, city}', {
                    "timestamp": 1234567890,
                    "report": "Age Report",
                    "results": [
                            { "name": "John", "age": 43, "city": "TownA" },
                            { "name": "Joe",  "age": 10, "city": "TownB" }
                    ]
            })
    [{'age': 43, 'city': 'TownA'}, {'age': 10, 'city': 'TownB'}]

Contents:

- Installation
- Tutorial
- API reference
  - jqpy.EmptyInput
  - jqpy.JQError
  - jqpy.JQMissingError
  - jqpy.JQProcessingError
  - jqpy.JQResultError
  - jqpy.JQRuntimeError
  - jqpy.JQTimeoutError
  - jqpy.JQUsageError
  - jqpy.JSON
  - jqpy.RawOutput
  - jqpy.jq

Back to top